@@ -2,8 +2,8 @@
 #
 # Copyright (C) Zenoss, Inc. 2013, all rights reserved.
 #
-# This content is made available according to terms specified in
-# License.zenoss under the directory where your Zenoss product is installed.
+# This content is made available according to terms specified in the LICENSE
+# file at the top-level directory of this package.
 #
 ##############################################################################
 
@@ -162,8 +162,8 @@ class SingleShotCommand(object):
         yield self._sender.send_request('delete', shell_id=shell_id)
 
 
-def create_single_shot_command(hostname, username, password):
-    sender = EtreeRequestSender(hostname, username, password)
+def create_single_shot_command(hostname, auth_type, username, password):
+    sender = EtreeRequestSender(hostname, auth_type, username, password)
     return SingleShotCommand(sender)
 
 
@@ -192,7 +192,9 @@ class LongRunningCommand(object):
     @defer.inlineCallbacks
     def receive(self):
         receive_elem = yield self._sender.send_request(
-            'receive', shell_id=self._shell_id, command_id=self._command_id)
+            'receive',
+            shell_id=self._shell_id,
+            command_id=self._command_id)
         stdout_parts = _find_stream(receive_elem, self._command_id, 'stdout')
         stderr_parts = _find_stream(receive_elem, self._command_id, 'stderr')
         self._exit_code = _find_exit_code(receive_elem, self._command_id)
@@ -217,8 +219,8 @@ class LongRunningCommand(object):
         defer.returnValue(CommandResponse(stdout, stderr, self._exit_code))
 
 
-def create_long_running_command(hostname, username, password):
-    sender = EtreeRequestSender(hostname, username, password)
+def create_long_running_command(hostname, auth_type, username, password):
+    sender = EtreeRequestSender(hostname, auth_type, username, password)
     return LongRunningCommand(sender)
 
 
@@ -267,9 +269,9 @@ class Typeperf(object):
         self._row_count = 0
 
 
-def create_typeperf(hostname, username, password):
+def create_typeperf(hostname, auth_type, username, password):
     long_running_command = create_long_running_command(
-        hostname, username, password)
+        hostname, auth_type, username, password)
     return Typeperf(long_running_command)
 
 
@@ -401,6 +403,6 @@ class RemoteShell(object):
 
 
 def create_remote_shell(
-        hostname, username, password, include_exit_codes=False):
-    sender = EtreeRequestSender(hostname, username, password)
+        hostname, auth_type, username, password, include_exit_codes=False):
+    sender = EtreeRequestSender(hostname, auth_type, username, password)
     return RemoteShell(sender, include_exit_codes)
